summaryrefslogtreecommitdiffstats
path: root/chrome/browser/cocoa/chrome_event_processing_window.h
diff options
context:
space:
mode:
authorviettrungluu@chromium.org <viettrungluu@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-02-11 21:11:15 +0000
committerviettrungluu@chromium.org <viettrungluu@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-02-11 21:11:15 +0000
commitec3625e3d6de06cbb2bf79531af92eaf61c14bf8 (patch)
treee89c13d16b90851fbebecc34784c871047af4ef4 /chrome/browser/cocoa/chrome_event_processing_window.h
parentc18388fbdee1812b724d90b7736291502e6dd68f (diff)
downloadchromium_src-ec3625e3d6de06cbb2bf79531af92eaf61c14bf8.zip
chromium_src-ec3625e3d6de06cbb2bf79531af92eaf61c14bf8.tar.gz
chromium_src-ec3625e3d6de06cbb2bf79531af92eaf61c14bf8.tar.bz2
Mac: (for fullscreen mode) make key redispatch handle "misdirected" events.
Moving things between windows can lead to the key redispatch getting an event for the wrong window. This makes the redispatcher synthesize new events in that case. BUG=31638 TEST=Compiles/unit tests. Enable fullscreen mode (in code), and switch back and forth between regular and fullscreen mode (esp. while loading slow web pages) like mad. Review URL: http://codereview.chromium.org/594025 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@38812 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/cocoa/chrome_event_processing_window.h')
-rw-r--r--chrome/browser/cocoa/chrome_event_processing_window.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/chrome/browser/cocoa/chrome_event_processing_window.h b/chrome/browser/cocoa/chrome_event_processing_window.h
index 0d9cfbb..4159be7 100644
--- a/chrome/browser/cocoa/chrome_event_processing_window.h
+++ b/chrome/browser/cocoa/chrome_event_processing_window.h
@@ -18,12 +18,13 @@
BOOL eventHandled_;
}
// Sends an event to |NSApp sendEvent:|, but also makes sure that it's not
// short-circuited to the RWHV. This is used to send keyboard events to the menu
// and the cmd-` handler if a keyboard event comes back unhandled from the
-// renderer.
+// renderer. The event must be of type |NSKeyDown|, |NSKeyUp|, or
+// |NSFlagsChanged|.
// Returns |YES| if |event| has been handled.
-- (BOOL)redispatchEvent:(NSEvent*)event;
+- (BOOL)redispatchKeyEvent:(NSEvent*)event;
// See global_keyboard_shortcuts_mac.h for details on the next two functions.
@@ -18,12 +18,13 @@
BOOL eventHandled_;
}
-// Sends an event to |NSApp sendEvent:|, but also makes sure that it's not
+// Sends a key event to |NSApp sendEvent:|, but also makes sure that it's not
// short-circuited to the RWHV. This is used to send keyboard events to the menu
// and the cmd-` handler if a keyboard event comes back unhandled from the